@@ -3,8 +3,11 @@ test_that("is_interactive() | general test", {
 })
 
 test_that("require_namespace() | general test", {
-    expect_equal(require_namespace("base"),
-                 requireNamespace("base", quietly = TRUE))
+    expect_equal(require_namespace(
+        "base"
+    ),
+    requireNamespace("base", quietly = TRUE)
+    )
 })
 
 test_that("read_line() | general test", {
